(ns puppetlabs.puppetdb.facts-test
  (:require [puppetlabs.puppetdb.facts :refer :all]
            [clojure.test :refer :all]))

(deftest test-str->num
  (are [n s] (= n (str->num s))

       10 "10"
       123 "123"
       0 "0"
       nil "foo"
       nil "123foo"))

(deftest test-unencode-path-segment
  (are [path-segment s] (= path-segment (unencode-path-segment s))
       "\"foo\"" "\"foo\""
       "\"\"foo\"\"" "\"\"foo\"\""
       "foo" "foo"
       "123" "\"123\""
       "\"123foo\"" "\"123foo\""
       1 "1"
       123 "123"))

(deftest test-factpath-to-string-and-reverse
  (let [data
        [["foo#~bar"      ["foo" "bar"]]
         ["foo"           ["foo"]]
         ["foo#~bar#~baz" ["foo" "bar" "baz"]]
         ["foo\\#\\~baz"  ["foo#~baz"]]
         ["foo#~0"        ["foo" 0]]
         ["foo#~\"123\""  ["foo" "123"]]]]
    (doseq [[r l] data]
      (is (= (string-to-factpath r) l))
      (is (= r (factpath-to-string l))))))
